Daemon rucio-atropos — Rucio 1.2 documentation

# Daemon rucio-atropos

    usage: rucio-atropos [-h] [--run-once] [--dry-run] [--threads THREADS]
                         [--bulk BULK] [--grace-period GRACE_PERIOD]
                         [--date-check DATE_CHECK]

## Named Arguments

`--run-once` | Runs one loop iteration Default: False
`--dry-run` | Dry run mode Default: False
`--threads` | Concurrency control: number of threads Default: 1
`--bulk` | Bulk control: number of requests per cycle Default: 1000
`--grace-period` | Grace period for the rules. In seconds !!! Default: 86400
`--date-check` | Date when the lifetime model will be applied. Cannot be used for a date in the future if dry-run is not enabled